==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
export let WebAccordionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAccordionDescriptionMetadata extends Base {
        static b(a) {
            if (WebAccordionDescriptionMetadata.a == null) {
                WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
            }
            if (a.j(WebAccordionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebAccordionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Accordion");
            a.item("__tagNameWC", "String:igc-accordion");
            a.item("SingleExpand", "Boolean");
        }
        static d(a) {
            WebAccordionDescriptionMetadata.b(a);
            a.aa("WebAccordion", () => new WebAccordionDescription());
            a.z("WebAccordion", WebAccordionDescriptionMetadata.a);
        }
    }
    WebAccordionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebAccordionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAccordionDescription } from "./WebAccordionDescription";
/**
 * @hidden
 */
export let WebAccordionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAccordionDescriptionMetadata extends Base {
        static b(a) {
            if (WebAccordionDescriptionMetadata.a == null) {
                WebAccordionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAccordionDescriptionMetadata.c(WebAccordionDescriptionMetadata.a);
            }
            if (a.k(WebAccordionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebAccordionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Accordion");
            a.item("__tagNameWC", "String:igc-accordion");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("SingleExpand", "Boolean");
        }
        static d(a) {
            WebAccordionDescriptionMetadata.b(a);
            a.ac("WebAccordion", () => new WebAccordionDescription());
            a.ab("WebAccordion", WebAccordionDescriptionMetadata.a);
        }
    }
    WebAccordionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebAccordionDescriptionMetadata, 'WebAccordionDescriptionMetadata');
    WebAccordionDescriptionMetadata.a = null;
    return WebAccordionDescriptionMetadata;
})();
